# UI/UX Feedback

**ID:** Feedback-20260321-090349
**URL:** http://127.0.0.1:5858/
**Date:** 2026-03-21 09:05:26

## Selected Elements

- `{'selector': 'span:nth-child(1)', 'parents': ['div#page-root', 'header.top-menu', 'div.menu-actions', 'div#mode-toggle']}`

## Feedback

when we try to create an idea with knowledge base reference, it fails to create the idea, the composing idea action still in progress

## Screenshot

![Screenshot](./page-screenshot.png)
